package com.ruoyi.project.aerial.service;

import java.util.List;
import com.ruoyi.project.aerial.domain.TAerialDevVideo;

/**
 * 鸟瞰图设备视频Service接口
 * 
 * @author ssy
 * @date 2025-04-03
 */
public interface ITAerialDevVideoService 
{
    /**
     * 查询鸟瞰图设备视频
     * 
     * @param id 鸟瞰图设备视频ID
     * @return 鸟瞰图设备视频
     */
    public TAerialDevVideo selectTAerialDevVideoById(Long id);

    /**
     * 查询鸟瞰图设备视频列表
     * 
     * @param tAerialDevVideo 鸟瞰图设备视频
     * @return 鸟瞰图设备视频集合
     */
    public List<TAerialDevVideo> selectTAerialDevVideoList(TAerialDevVideo tAerialDevVideo);

    /**
     * 新增鸟瞰图设备视频
     * 
     * @param tAerialDevVideo 鸟瞰图设备视频
     * @return 结果
     */
    public int insertTAerialDevVideo(TAerialDevVideo tAerialDevVideo);

    /**
     * 修改鸟瞰图设备视频
     * 
     * @param tAerialDevVideo 鸟瞰图设备视频
     * @return 结果
     */
    public int updateTAerialDevVideo(TAerialDevVideo tAerialDevVideo);

    /**
     * 批量删除鸟瞰图设备视频
     * 
     * @param ids 需要删除的鸟瞰图设备视频ID
     * @return 结果
     */
    public int deleteTAerialDevVideoByIds(Long[] ids);

    /**
     * 删除鸟瞰图设备视频信息
     * 
     * @param id 鸟瞰图设备视频ID
     * @return 结果
     */
    public int deleteTAerialDevVideoById(Long id);
}
